from interactions.ext.base import Base
from interactions.ext.version import Version, VersionAuthor

from interactions import Client

from .extension import Localization

__all__ = ("version", "base", "setup")

__version__ = "0.0.1"

version = Version(
    version=__version__, author=VersionAuthor(name="Damego", email="damego.dev@gmail.com")
)
base = Base(
    name="interactions-i18n",
    version=version,
    link="https://github.com/Damego/interactions-i18n",
    description="Add localization support to your interactions.py bot",
    packages=["interactions.ext.i18n"],
    requirements=["discord-py-interactions>=4.3.2"],
)


def setup(client: Client):
    client.i18n = Localization(client)
    return client.i18n



import json
from logging import getLogger
from os import PathLike
from pathlib import Path
from typing import Dict, Optional

from interactions import MISSING, Client, Locale

__all__ = ("Localization",)

log = getLogger("i18n")


class Localization:
    def __init__(self, client: Client):
        self.client: Client = client
        self._locales: Dict[str, Dict[Locale, str]] = {}

    @property
    def locales(self) -> Dict[str, Dict[Locale, str]]:
        return self._locales

    def load(self, path: PathLike):
        _path = Path(path)

        if _path.is_file():
            locale_data = self.__load_file(_path)
            if not locale_data:
                return
            self.__load_localization(_path, locale_data)

        for file in _path.iterdir():
            locale_data = self.__load_file(file)
            if not locale_data:
                continue

            self.__load_localization(file, locale_data)

    def __load_file(self, file: Path) -> Optional[dict]:
        if file.suffix != ".json":
            log.debug(f"File {file} is not json format. Skipping...")
            return

        with open(file, "r", encoding="utf-8") as _file:
            try:
                return json.load(_file)
            except json.JSONDecodeError:
                log.exception(f"Couldn't load file {file}!")

    def __load_localization(self, file: Path, locale_data: dict):
        locale = Locale(file.name.removesuffix(".json"))
        for key in list(locale_data.keys()):
            _data = {locale: locale_data.pop(key)}

            if key not in self._locales:
                self._locales[key] = {}
            self._locales[key] |= _data

    def _get_value(self, key: str) -> Optional[str]:
        return self.locales.get(key, MISSING)

    def get_name(self, key: str) -> Optional[str]:
        _key: str = f"{key.upper()}_NAME"
        return self._get_value(_key)

    def get_description(self, key: str) -> Optional[str]:
        _key: str = f"{key.upper()}_DESCRIPTION"
        return self._get_value(_key)



import re
from codecs import open

from setuptools import setup

# Package information
AUTHOR = "Damego"
AUTHOR_EMAIL = "damego.dev@gmail.com"
DESCRIPTION = "Add localization support to your interactions.py bot"
PROJECT_NAME = "interactions-i18n"
MAIN_PACKAGE_NAME = "interactions.ext.i18n"
URL = "https://github.com/Damego/interactions-i18n"

with open("README.md", "r", encoding="utf-8") as f:
    README = f.read()

with open("interactions/ext/i18n/base.py") as fp:
    VERSION = re.search('__version__ = "([^"]+)"', fp.read())[1]

setup(
    name=PROJECT_NAME,
    version=VERSION,
    author=AUTHOR,
    author_email=AUTHOR_EMAIL,
    description=DESCRIPTION,
    include_package_data=True,
    install_requires=["discord-py-interactions>=4.3.2"],
    license="MIT License",
    long_description=README,
    long_description_content_type="text/markdown",
    url=URL,
    packages=["interactions.ext.i18n"],
    python_requires=">=3.8",
    classifiers=[
        "Intended Audience :: Developers",
        "License :: OSI Approved :: MIT License",
        "Natural Language :: English",
        "Operating System :: OS Independent",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Topic :: Internet",
        "Topic :: Software Development :: Libraries :: Python Modules",
        "Topic :: Software Development :: Libraries",
        "Topic :: Utilities",
    ],
)
